measuretools.get_next_measure_from_component
============================================

.. autofunction:: abjad.tools.measuretools.get_next_measure_from_component.get_next_measure_from_component
   :noindex:
